<?php
 // zobrazovac obrazku ve slozce
 // pouziti: umistete soubor do slozky, ktera obsahuje obrazky
 // neprohledava podslozky a ignoruje jine soubory, nez jpg.
 // soubory jsou serazeny podle data porizeni (z EXIFu), pokud neni EXIF dostupny, pouzije se datum souboru.

/*
licence:
https://gnu.org/licenses/gpl.html

autor neručí za škody způsobené používáním tohoto skriptu.
*/

$zobrazitOdkazNaSoubor = 1;
 // pripustne hodnoty: true nebo 1 = Ano; false nebo 0 = Ne.
 // rika, zda se u obrazku take zobrazi odkaz na prime zobrazeni zdrojoveho souboru.

$smerOdNejnovejsich = 0;
 // pripustne hodnoty: true nebo 1 = Ano; false nebo 0 = Ne.
 // rika, zda se nejvyse nahore zobrazi nejnovejsi fotka. Pokud ne, pak se zobrazi nahore nejstarsi fotka.

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>fotky</title>
<meta http-equiv="content-type" content="application/xhtml+xml; charset=utf-8" />
</head>
<body>
<?php


$adresar = opendir(".");
$nalezen = false;
while ($soubor = readdir($adresar)){
  $pripona = explode(".",$soubor);
  if (strtolower($pripona[(count($pripona)-1)]) == "jpg") {
    $nalezen = true;
    
    $exif = exif_read_data($soubor);
    $obrazek = new Obrazek($exif, $soubor);
    $misto = $obrazek->datum;
    while (isset($pole[$misto])) {
      $misto++;
    }
    $pole[$misto] = $obrazek;
    
  }
}

closedir($adresar);

if ($nalezen) {
  
  if ($smerOdNejnovejsich) {
    krsort($pole);
  } else {
    ksort($pole);
  }
  
  foreach ($pole as $datum=>$obrazek) {
  	echo "<p>";
  	echo $obrazek->nazev;
  	echo ", pořízen ";
  	echo $obrazek->writeDatum();
  	if ($zobrazitOdkazNaSoubor) {
      echo "<br /><a href='$obrazek->nazev'>odkaz</a><br />&nbsp;<br />";
    } else {
      echo "<br />&nbsp;<br />";
    }
  	
  	echo "<img alt='$obrazek->nazev' src=\"$obrazek->nazev\" width=\"".$obrazek->getZobrSirku()."\" height=\"".$obrazek->getZobrVysku()."\" />";
  
  	echo "</p>";
  	echo "<hr />";
  }
}

class Obrazek {
  public $sirka;
  public $vyska;
  public $datum;
  public $nazev;
  private $koefZmenseni;
  private static $maximalniRozmer = 1024;
  
  public function __construct($array, $nazevSouboru) {
    $exif = false;
    $rozmer = false;
    if (isset($array["ExifImageWidth"], $array["ExifImageLength"])) {
      $rozmer = true;
      if (isset($array["DateTimeOriginal"], $array["FileName"])) {
        $exif = true;
      }
    }
  
    if ($exif) {
      $this->sirka = $array["ExifImageWidth"];
      $this->vyska = $array["ExifImageLength"];
      $this->datum = strtotime($array["DateTimeOriginal"]);
      $this->nazev = $array["FileName"];
    } else {
      $size = getimagesize ($nazevSouboru);
      $this->sirka = $size[0];
      $this->vyska = $size[1];
      $this->datum = filemtime($nazevSouboru);
      $this->nazev = $nazevSouboru;
    } 
  }
  
  public function writeDatum() {
    return date("j.n.Y v G:i", $this->datum);
  }
  
  public function getZobrSirku() {
    if (!isset($koefZmenseni)) $this->vypocitejKoef();
    return $this->koefZmenseni*$this->sirka;
  }
  
  public function getZobrVysku() {
    if (!isset($koefZmenseni)) $this->vypocitejKoef();
    return $this->koefZmenseni*$this->vyska;
  }
  
  private function vypocitejKoef() {
    if ($this->sirka > $this->vyska) {
      if ($this->sirka > self::$maximalniRozmer) {
        $this->koefZmenseni = self::$maximalniRozmer/$this->sirka;
      } else {
        $this->koefZmenseni = 1;
      }
    } else {
      if ($this->vyska > self::$maximalniRozmer) {
        $this->koefZmenseni = self::$maximalniRozmer/$this->sirka;
      } else {
        $this->koefZmenseni = 1;
      }
    }
  }
}
?>
</body>
</html>
